//**********************************************************************
// LogViewer
// =========
//
// Simple Event Log viewer whose only function is to show off the
// CRhsEventLog class.
//
// John Rennie
// jrennie@cix.compulink.co.uk
// 28th July 1999
//**********************************************************************

#ifndef STRICT
#define STRICT
#endif

#include <windows.h>
#include <stdio.h>
#include <string.h>
#include <RhsEventLog.h>


//**********************************************************************
// Function prototypes
// -------------------
//**********************************************************************

const char* GetLastErrorMessage(void);


//**********************************************************************
// Global variables
// ----------------
//**********************************************************************

#define SYNTAX \
"LogViewer <System|Security|Application> [<computer>]\n" \
"e.g. \"LogViewer System Fred\" to view the System Log on Fred\n"


//**********************************************************************
// Here we go
// ----------
//**********************************************************************

int main(int argc, char* argv[])
{ 
  char* computer;
  const char* msg;
  SYSTEMTIME st;
  CRhsEventLog log;

// Check the arguments

  if (argc == 2)
  { if (strcmp(argv[1], "-?") == 0 || strcmp(argv[1], "/?") == 0)
    { printf(SYNTAX);
      return 0;
    }
  }

  if (argc < 2 || argc > 3)
  { printf(SYNTAX);
    return 2;
  }

  AnsiLower(argv[1]);
  if (strcmp(argv[1], "system") != 0 && strcmp(argv[1], "security") != 0 && strcmp(argv[1], "application") != 0)
  { printf(SYNTAX);
    return 2;
  }

  if (argc == 3)
    computer = argv[2];
  else
    computer = NULL;

// Open the Event Log

  if (!log.OpenLog(argv[1], TRUE, computer))
  { printf("Cannot open the event log: %s\n", GetLastErrorMessage());
    return 2;
  }

// Move to the end of the log and start working backwards through it

  printf("No.    Date              Category    ID       Source     Computer\n");

  while (log.RecordAvailable())
  { log.Time(&st);

    printf("%-6i %02i/%02i/%02i %02i:%02i:%02i %10s %08x %-10s %-10s\n",
           log.RecordNumber(), 
           st.wDay, st.wMonth, st.wYear % 100, st.wHour, st.wMinute, st.wSecond,
           log.Category(), log.EventID(),
           log.Source(), log.Computer()
          );

    msg = log.Message();
    if (msg)
      printf("%s\n", msg);
    else
      printf("No message for this event\n\n");

    log.ReadRecord();
  }

// Close the log

  log.CloseLog();

// All done

  return 0;
}


//**********************************************************************
// GetLastErrorMessage
// -------------------
//**********************************************************************

const char* GetLastErrorMessage(void)
{ DWORD d;
  static char errmsg[1024];

  d = GetLastError();

  strcpy(errmsg, "<unknown error>");
  FormatMessage(FORMAT_MESSAGE_FROM_SYSTEM, 0, d, 0, errmsg, 1023, NULL);
  return(errmsg);
}


