//**********************************************************************
// CRhsEventLog
// ============
//
// Class to encapsulate the Windows NT Event Log
//
// John Rennie
// jrennie@cix.compulink.co.uk
// 28th July 1999
//**********************************************************************

#ifndef _INC_RHSEVENTLOG
#define _INC_RHSEVENTLOG

class CRhsEventLog
{
  public:
    CRhsEventLog();
    ~CRhsEventLog();

    BOOL OpenLog(int Type, BOOL ReadBack = FALSE, const char* Computer = NULL);
    BOOL OpenLog(char* Type, BOOL ReadBack = FALSE, const char* Computer = NULL);
    void CloseLog(void);

    BOOL ReadRecord(DWORD Offset = 0);
    inline BOOL RecordAvailable(void) { return m_Record ? TRUE : FALSE; }

    inline void SetDirection(BOOL ReadBack) { m_ReadDirection = ReadBack ? EVENTLOG_BACKWARDS_READ : EVENTLOG_FORWARDS_READ; }

    const char* Category(void);
    const char* Source(void);
    const char* Computer(void);
    BOOL        Time(SYSTEMTIME* st);
    const char* Message(void);

    inline DWORD RecordNumber(void) { return m_Record ? m_Record->RecordNumber :  (DWORD) -1; }
    inline DWORD Time(void)         { return m_Record ? m_Record->TimeGenerated : (DWORD) -1; }
    inline DWORD EventID(void)      { return m_Record ? m_Record->EventID :       (DWORD) -1; }
    inline DWORD EventType(void)    { return m_Record ? m_Record->EventType :     (DWORD) -1; }

    inline HANDLE hEventLog(void) { return m_hEventLog; }

  private:
    HANDLE m_hEventLog;

    char m_Computer[128];

    int m_LogType;  // 1=System, 2=Security, 3=Application, 0=not open

    DWORD m_ReadDirection; // Direction to read log

    EVENTLOGRECORD* m_Record;

    char* m_Message; // Holds message for event
};

#endif // _INC_RHSEVENTLOG

